osutil

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 12, 2018 License: BSD-3-Clause Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateSimLink(dst, src string) error

CreateSimLink creates a simulated link which is just a text file containing the real path dst is the file name to point to src is the file name of the link

func Executable

func Executable() (string, error)

Executable returns an absolute path to the currently executing program.

func ReadSimLink(link string) (string, error)

ReadSimLink a simulated link which is just a text file containing the real path link is the file name of the link

func Rename

func Rename(src, dst string) error

Types

This section is empty.

Jump to