Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateSimLink ¶ added in v0.1.1
CreateSimLink creates a simulated link which is just a text file containing the real path dst is the file name to point to src is the file name of the link
func Executable ¶
Executable returns an absolute path to the currently executing program.
func ReadSimLink ¶ added in v0.1.1
ReadSimLink a simulated link which is just a text file containing the real path link is the file name of the link
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.